@@ -44,6 +44,7 @@
 #include "tracker-miner-files.h"
 #include "tracker-config.h"
 #include "tracker-storage.h"
+#include "tracker-extract-watchdog.h"
 
 #define DISK_SPACE_CHECK_FREQUENCY 10
 #define SECONDS_PER_DAY 86400
@@ -65,6 +66,7 @@ struct ProcessFileData {
 struct TrackerMinerFilesPrivate {
 	TrackerConfig *config;
 	TrackerStorage *storage;
+	TrackerExtractWatchdog *extract_watchdog;
 
 	GVolumeMonitor *volume_monitor;
 
@@ -552,6 +554,8 @@ miner_files_initable_init (GInitable     *initable,
 
 	disk_space_check_start (mf);
 
+	mf->private->extract_watchdog = tracker_extract_watchdog_new ();
+
 	return TRUE;
 }
 
@@ -604,6 +608,8 @@ miner_files_finalize (GObject *object)
 	mf = TRACKER_MINER_FILES (object);
 	priv = mf->private;
 
+	g_clear_object (&priv->extract_watchdog);
+
 	if (priv->config) {
 		g_signal_handlers_disconnect_by_func (priv->config,
 		                                      low_disk_space_limit_cb,
@@ -734,16 +740,16 @@ set_up_mount_point_type (TrackerMinerFiles *miner,
 	                        removable_device_urn, removable_device_urn);
 
 	g_string_append_printf (accumulator,
-	                        "INSERT INTO <%s> { <%s> a tracker:Volume; tracker:isRemovable %s } ",
-	                        removable_device_urn, removable_device_urn, removable ? "true" : "false");
+	                        "INSERT INTO <" TRACKER_OWN_GRAPH_URN "> { <%s> a tracker:Volume; tracker:isRemovable %s } ",
+	                        removable_device_urn, removable ? "true" : "false");
 
 	g_string_append_printf (accumulator,
 	                        "DELETE { <%s> tracker:isOptical ?unknown } WHERE { <%s> a tracker:Volume; tracker:isOptical ?unknown } ",
 	                        removable_device_urn, removable_device_urn);
 
 	g_string_append_printf (accumulator,
-	                        "INSERT INTO <%s> { <%s> a tracker:Volume; tracker:isOptical %s } ",
-	                        removable_device_urn, removable_device_urn, optical ? "true" : "false");
+	                        "INSERT INTO <" TRACKER_OWN_GRAPH_URN "> { <%s> a tracker:Volume; tracker:isOptical %s } ",
+	                        removable_device_urn, optical ? "true" : "false");
 }
 
 static void
@@ -804,17 +810,17 @@ set_up_mount_point (TrackerMinerFiles *miner,
 
                 if (mount_name) {
                         g_string_append_printf (queries,
-                                                "INSERT INTO <%s> { <%s> a tracker:Volume; tracker:isMounted true; nie:title \"%s\" } ",
-                                                removable_device_urn, removable_device_urn, mount_name);
+                                                "INSERT INTO <" TRACKER_OWN_GRAPH_URN "> { <%s> a tracker:Volume; tracker:isMounted true; nie:title \"%s\" } ",
+                                                removable_device_urn, mount_name);
                 } else {
                         g_string_append_printf (queries,
-                                                "INSERT INTO <%s> { <%s> a tracker:Volume; tracker:isMounted true } ",
-                                                removable_device_urn, removable_device_urn);
+                                                "INSERT INTO <" TRACKER_OWN_GRAPH_URN "> { <%s> a tracker:Volume; tracker:isMounted true } ",
+                                                removable_device_urn);
                 }
 
                 g_string_append_printf (queries,
-                                        "INSERT { GRAPH <%s> { ?do tracker:available true } } WHERE { ?do nie:dataSource <%s> } ",
-                                        removable_device_urn, removable_device_urn);
+                                        "INSERT { GRAPH <" TRACKER_OWN_GRAPH_URN "> { ?do tracker:available true } } WHERE { ?do nie:dataSource <%s> } ",
+                                        removable_device_urn);
 	} else {
 		gchar *now;
 
@@ -828,16 +834,16 @@ set_up_mount_point (TrackerMinerFiles *miner,
 		                        removable_device_urn, removable_device_urn);
 
 		g_string_append_printf (queries,
-		                        "INSERT INTO <%s> { <%s> a tracker:Volume; tracker:unmountDate \"%s\" } ",
-		                        removable_device_urn, removable_device_urn, now);
+		                        "INSERT INTO <" TRACKER_OWN_GRAPH_URN "> { <%s> a tracker:Volume; tracker:unmountDate \"%s\" } ",
+		                        removable_device_urn, now);
 
 		g_string_append_printf (queries,
 		                        "DELETE { <%s> tracker:isMounted ?unknown } WHERE { <%s> a tracker:Volume; tracker:isMounted ?unknown } ",
 		                        removable_device_urn, removable_device_urn);
 
 		g_string_append_printf (queries,
-		                        "INSERT INTO <%s> { <%s> a tracker:Volume; tracker:isMounted false } ",
-		                        removable_device_urn, removable_device_urn);
+		                        "INSERT INTO <" TRACKER_OWN_GRAPH_URN "> { <%s> a tracker:Volume; tracker:isMounted false } ",
+		                        removable_device_urn);
 
 		g_string_append_printf (queries,
 		                        "DELETE { ?do tracker:available true } WHERE { ?do nie:dataSource <%s> } ",
