@@ -541,11 +541,6 @@ tags_view_add_tags_cb (GObject      *source_object,
 		if (cursor) {
 			g_object_unref (cursor);
 		}
-
-		if (error) {
-			show_error_dialog (error);
-			g_error_free (error);
-		}
 	}
 }
 
